.. image:: _static/cabinetry_logo_small.png
  :width: 480
  :alt: cabinetry logo
  :align: center

cabinetry
==============================

.. toctree::
    :hidden:
    :maxdepth: 1

    core
    advanced
    config
    cli
    api
    license

``cabinetry`` is a Python library for building and steering binned template fits.
It interfaces many other libraries to make it easy for an analyzer to run their statistical inference pipeline.

This documentation can be viewed `on Read the Docs <https://cabinetry.readthedocs.io/>`_ or locally via

.. code-block:: bash

    sphinx-build docs docs/_build
    open docs/_build/index.html

See the `README on github <https://github.com/alexander-held/cabinetry/blob/master/README.md>`_ for a simple example of using ``cabinetry``, and the `cabinetry-tutorials <https://github.com/cabinetry/cabinetry-tutorials>`_ repository for a more in-depth version.

Presentations of cabinetry
----------------------------

- `vCHEP 2021 <https://indico.cern.ch/event/948465/>`_

  - short talk: https://indico.cern.ch/event/948465/contributions/4324154/
  - associated paper: `10.5281/zenodo.4627037 <https://doi.org/10.5281/zenodo.4627037>`_

- `PyHEP 2021 <https://indico.cern.ch/event/1019958/>`_

  - notebook talk: https://indico.cern.ch/event/1019958/contributions/4421868/

Acknowledgements
----------------
This work was supported by the U.S. National Science Foundation (NSF) cooperative agreement `OAC-1836650 (IRIS-HEP) <https://nsf.gov/awardsearch/showAward?AWD_ID=1836650>`_.
